==> openssm_dev-0.1.6.6.tar.gz: openssm_dev-0.1.6.6/openssm/core/backend/base_backend.py <==
"""Base backend."""


from openssm.core.inferencer.abstract_inferencer import AbstractInferencer
from openssm.core.backend.abstract_backend import AbstractBackend


class BaseBackend(AbstractBackend):
    """Base backend."""

    def __init__(self):
        self.facts = set()
        self.inferencers = set()
        self.heuristics = set()

    def __repr__(self) -> str:
        """Return Backend instance's string representation."""
        return 'BaseBackend'

    # pylint: disable=unused-argument
    def query(self, conversation_id: str, user_input: str) -> list[dict]:
        return []

    def load_all(self):
        """
        The base backend does not load anything.
        It gets all its facts, inferencers, and heuristics
        through the add_* methods.
        """

    def add_fact(self, fact: str):
        self.facts.add(fact)

    def add_inferencer(self, inferencer: AbstractInferencer):
        self.inferencers.add(inferencer)

    def add_heuristic(self, heuristic: str):
        self.heuristics.add(heuristic)

    def list_facts(self):
        return self.facts

    def list_inferencers(self):
        return self.inferencers

    def list_heuristics(self):
        return self.heuristics

    def select_facts(self, criteria):
        """
        The base backend simply returns all facts.
        """
        assert criteria is not None
        return self.list_facts()

    def select_inferencers(self, criteria):
        """
        The base backend simply returns all inferencers.
        """
        assert criteria is not None
        return self.list_inferencers()

    def select_heuristics(self, criteria):
        """
        The base backend simply returns all heuristics.
        """
        assert criteria is not None
        return self.list_heuristics()

==> openssm_dev-0.1.6.9.tar.gz: openssm_dev-0.1.6.9/openssm/core/backend/base_backend.py <==
"""Base backend."""


from openssm.core.inferencer.abstract_inferencer import AbstractInferencer
from openssm.core.backend.abstract_backend import AbstractBackend
from openssm.utils.logs import Logs


class BaseBackend(AbstractBackend):
    """Base backend."""

    def __init__(self):
        self._facts = set()
        self._inferencers = set()
        self._heuristics = set()

    # pylint: disable=unused-argument
    @Logs.do_log_entry_and_exit()
    def query(self, user_input: list[dict], conversation_id: str = None) -> dict:
        """
        The base backend merely calls query2 and returns the first element of the tuple.
        """
        # pylint: disable=unused-variable
        return {"response": None, "response_object": None}

    def load_all(self):
        """
        The base backend does not load anything.
        It gets all its facts, inferencers, and heuristics
        through the add_* methods.
        """

    def add_fact(self, fact: str):
        self.facts.add(fact)

    def add_inferencer(self, inferencer: AbstractInferencer):
        self.inferencers.add(inferencer)

    def add_heuristic(self, heuristic: str):
        self.heuristics.add(heuristic)

    @property
    def facts(self):
        return self._facts

    @property
    def inferencers(self):
        return self._inferencers

    @property
    def heuristics(self):
        return self._heuristics

    def select_facts(self, criteria):
        """
        The base backend simply returns all facts.
        """
        assert criteria is not None
        return self.facts

    def select_inferencers(self, criteria):
        """
        The base backend simply returns all inferencers.
        """
        assert criteria is not None
        return self.inferencers

    def select_heuristics(self, criteria):
        """
        The base backend simply returns all heuristics.
        """
        assert criteria is not None
        return self.heuristics

    def save(self, storage_dir: str):
        """Saves to the specified directory."""
        pass

    def load(self, storage_dir: str):
        """Loads from the specified directory."""
        pass
